@@ -5,7 +5,7 @@ test_check("parsedate")
 
 run <- function(tz) {
   source("testthat/helper.R")
-  local_timezone(tz)
+  withr::local_timezone(tz)
   test_check("parsedate")
 }
 
